
#ifndef KIRIGAMIPLATFORM_EXPORT_H
#define KIRIGAMIPLATFORM_EXPORT_H

#ifdef KIRIGAMIPLATFORM_STATIC_DEFINE
#  define KIRIGAMIPLATFORM_EXPORT
#  define KIRIGAMIPLATFORM_NO_EXPORT
#else
#  ifndef KIRIGAMIPLATFORM_EXPORT
#    ifdef KirigamiPlatform_EXPORTS
        /* We are building this library */
#      define KIRIGAMIPLATFORM_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define KIRIGAMIPLATFORM_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef KIRIGAMIPLATFORM_NO_EXPORT
#    define KIRIGAMIPLATFORM_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef KIRIGAMIPLATFORM_DECL_DEPRECATED
#  define KIRIGAMIPLATFORM_DECL_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef KIRIGAMIPLATFORM_DECL_DEPRECATED_EXPORT
#  define KIRIGAMIPLATFORM_DECL_DEPRECATED_EXPORT KIRIGAMIPLATFORM_EXPORT KIRIGAMIPLATFORM_DECL_DEPRECATED
#endif

#ifndef KIRIGAMIPLATFORM_DECL_DEPRECATED_NO_EXPORT
#  define KIRIGAMIPLATFORM_DECL_DEPRECATED_NO_EXPORT KIRIGAMIPLATFORM_NO_EXPORT KIRIGAMIPLATFORM_DECL_DEPRECATED
#endif

/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef KIRIGAMIPLATFORM_NO_DEPRECATED
#    define KIRIGAMIPLATFORM_NO_DEPRECATED
#  endif
#endif
#include <kirigamiplatform_version.h>

#undef KIRIGAMIPLATFORM_DECL_DEPRECATED
#define KIRIGAMIPLATFORM_DECL_DEPRECATED [[deprecated]]

#undef KIRIGAMIPLATFORM_DECL_DEPRECATED_EXPORT
#define KIRIGAMIPLATFORM_DECL_DEPRECATED_EXPORT KIRIGAMIPLATFORM_EXPORT KIRIGAMIPLATFORM_DECL_DEPRECATED

#undef KIRIGAMIPLATFORM_DECL_DEPRECATED_NO_EXPORT
#define KIRIGAMIPLATFORM_DECL_DEPRECATED_NO_EXPORT KIRIGAMIPLATFORM_NO_EXPORT KIRIGAMIPLATFORM_DECL_DEPRECATED

#define KIRIGAMIPLATFORM_DECL_DEPRECATED_TEXT(text) [[deprecated(text)]]

#if defined(KIRIGAMIPLATFORM_NO_DEPRECATED)
#  undef KIRIGAMIPLATFORM_DEPRECATED
#  define KIRIGAMIPLATFORM_DEPRECATED_EXPORT KIRIGAMIPLATFORM_EXPORT
#  define KIRIGAMIPLATFORM_DEPRECATED_NO_EXPORT KIRIGAMIPLATFORM_NO_EXPORT
#elif defined(KIRIGAMIPLATFORM_NO_DEPRECATED_WARNINGS)
#  define KIRIGAMIPLATFORM_DEPRECATED
#  define KIRIGAMIPLATFORM_DEPRECATED_EXPORT KIRIGAMIPLATFORM_EXPORT
#  define KIRIGAMIPLATFORM_DEPRECATED_NO_EXPORT KIRIGAMIPLATFORM_NO_EXPORT
#else
#  define KIRIGAMIPLATFORM_DEPRECATED KIRIGAMIPLATFORM_DECL_DEPRECATED
#  define KIRIGAMIPLATFORM_DEPRECATED_EXPORT KIRIGAMIPLATFORM_DECL_DEPRECATED_EXPORT
#  define KIRIGAMIPLATFORM_DEPRECATED_NO_EXPORT KIRIGAMIPLATFORM_DECL_DEPRECATED_NO_EXPORT
#endif

/* No deprecated API had been removed from build */
#define KIRIGAMIPLATFORM_EXCLUDE_DEPRECATED_BEFORE_AND_AT 0

#define KIRIGAMIPLATFORM_BUILD_DEPRECATED_SINCE(major, minor) 1

#ifdef KIRIGAMIPLATFORM_NO_DEPRECATED
#  define KIRIGAMIPLATFORM_DISABLE_DEPRECATED_BEFORE_AND_AT KIRIGAMIPLATFORM_VERSION
#endif
#ifdef KIRIGAMIPLATFORM_NO_DEPRECATED_WARNINGS
#  define KIRIGAMIPLATFORM_DEPRECATED_WARNINGS_SINCE 0
#endif

#ifndef KIRIGAMIPLATFORM_DEPRECATED_WARNINGS_SINCE
#  ifdef KIRIGAMIPLATFORM_DISABLE_DEPRECATED_BEFORE_AND_AT
#    define KIRIGAMIPLATFORM_DEPRECATED_WARNINGS_SINCE KIRIGAMIPLATFORM_DISABLE_DEPRECATED_BEFORE_AND_AT
#  else
#    define KIRIGAMIPLATFORM_DEPRECATED_WARNINGS_SINCE KIRIGAMIPLATFORM_VERSION
#  endif
#endif

#ifndef KIRIGAMIPLATFORM_DISABLE_DEPRECATED_BEFORE_AND_AT
#  define KIRIGAMIPLATFORM_DISABLE_DEPRECATED_BEFORE_AND_AT 0x60000
#endif

#ifdef KIRIGAMIPLATFORM_DEPRECATED
#  define KIRIGAMIPLATFORM_ENABLE_DEPRECATED_SINCE(major, minor) (((major<<16)|(minor<<8)) > KIRIGAMIPLATFORM_DISABLE_DEPRECATED_BEFORE_AND_AT)
#else
#  define KIRIGAMIPLATFORM_ENABLE_DEPRECATED_SINCE(major, minor) 0
#endif

#if KIRIGAMIPLATFORM_DEPRECATED_WARNINGS_SINCE >= 0x61800
#  define KIRIGAMIPLATFORM_DEPRECATED_VERSION_6_24(text) KIRIGAMIPLATFORM_DECL_DEPRECATED_TEXT(text)
#else
#  define KIRIGAMIPLATFORM_DEPRECATED_VERSION_6_24(text)
#endif
#define KIRIGAMIPLATFORM_DEPRECATED_VERSION_6(minor, text)      KIRIGAMIPLATFORM_DEPRECATED_VERSION_6_##minor(text)
#define KIRIGAMIPLATFORM_DEPRECATED_VERSION(major, minor, text) KIRIGAMIPLATFORM_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
#define KIRIGAMIPLATFORM_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KIRIGAMIPLATFORM_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)

#endif /* KIRIGAMIPLATFORM_EXPORT_H */
