// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef KIRIGAMIPLATFORM_VERSION_H
#define KIRIGAMIPLATFORM_VERSION_H

#define KIRIGAMIPLATFORM_VERSION_STRING "6.28.0"
#define KIRIGAMIPLATFORM_VERSION_MAJOR 6
#define KIRIGAMIPLATFORM_VERSION_MINOR 28
#define KIRIGAMIPLATFORM_VERSION_PATCH 0
#define KIRIGAMIPLATFORM_VERSION ((6<<16)|(28<<8)|(0))

#endif
